Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/supermerill/SuperSlicer.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEnrico Turri <enricoturri@seznam.cz>2019-04-25 10:46:26 +0300
committerEnrico Turri <enricoturri@seznam.cz>2019-04-25 10:46:26 +0300
commit11490dfb066e56829a6a11d63d29cde7d0956846 (patch)
tree9ae694cc38cf5137c9a3cdf9f3b961675a038537 /src/slic3r/GUI/3DScene.hpp
parentec2f319a3d7cce7958a750e142d06c3921e7bf84 (diff)
Rectangle selection in 3D scene -> hovering detection
Diffstat (limited to 'src/slic3r/GUI/3DScene.hpp')
-rw-r--r--src/slic3r/GUI/3DScene.hpp9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/slic3r/GUI/3DScene.hpp b/src/slic3r/GUI/3DScene.hpp
index 88547359e..fa7d6f7d1 100644
--- a/src/slic3r/GUI/3DScene.hpp
+++ b/src/slic3r/GUI/3DScene.hpp
@@ -225,7 +225,8 @@ private:
class GLVolume {
public:
static const float SELECTED_COLOR[4];
- static const float HOVER_COLOR[4];
+ static const float HOVER_SELECT_COLOR[4];
+ static const float HOVER_DESELECT_COLOR[4];
static const float OUTSIDE_COLOR[4];
static const float SELECTED_OUTSIDE_COLOR[4];
static const float DISABLED_COLOR[4];
@@ -296,8 +297,10 @@ public:
bool shader_outside_printer_detection_enabled;
// Wheter or not this volume is outside print volume.
bool is_outside;
- // Boolean: Is mouse over this object?
- bool hover;
+ // Boolean: Is mouse over this object to select it ?
+ bool hover_select;
+ // Boolean: Is mouse over this object to deselect it ?
+ bool hover_deselect;
// Wheter or not this volume has been generated from a modifier
bool is_modifier;
// Wheter or not this volume has been generated from the wipe tower